@@ -25,12 +25,14 @@ bool SearchFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &
 
     const QString & displayName = modelIndex.data(Qt::DisplayRole).toString();
     const QString & name = modelIndex.data(AppsModel::NameRole).toString();
-    const QString & transliterated = modelIndex.data(AppsModel::TransliteratedRole).toString();
+    const QString & transliterated = modelIndex.data(AppsModel::AllTransliteratedRole).toString();
     const QString & jianpin = Dtk::Core::firstLetters(displayName).join(',');
 
     auto nameCopy = name;
     nameCopy = nameCopy.toLower();
     nameCopy.replace(" ", "");
 
-    return displayName.contains(searchPattern) || nameCopy.contains(searchPattern) || transliterated.contains(searchPattern) || jianpin.contains(searchPattern);
+    QString searchPatternDelBlank = searchPattern.pattern().toLower().remove(" ");
+
+    return displayName.contains(searchPatternDelBlank) || nameCopy.contains(searchPatternDelBlank) || transliterated.contains(searchPatternDelBlank) || jianpin.contains(searchPatternDelBlank);
 }
